@@ -19,6 +19,7 @@ import (
 	"github.com/lima-vm/lima/pkg/driver"
 	"github.com/lima-vm/lima/pkg/driverutil"
 	"github.com/lima-vm/lima/pkg/networks"
+	"github.com/lima-vm/lima/pkg/osutil"
 
 	"github.com/lima-vm/lima/pkg/cidata"
 	guestagentapi "github.com/lima-vm/lima/pkg/guestagent/api"
@@ -48,12 +49,13 @@ type HostAgent struct {
 	onClose         []func() error // LIFO
 
 	driver   driver.Driver
-	sigintCh chan os.Signal
+	signalCh chan os.Signal
 
 	eventEnc   *json.Encoder
 	eventEncMu sync.Mutex
 
-	vSockPort int
+	vSockPort  int
+	virtioPort string
 
 	clientMu sync.RWMutex
 	client   guestagentclient.GuestAgentClient
@@ -78,7 +80,7 @@ func WithNerdctlArchive(s string) Opt {
 // New creates the HostAgent.
 //
 // stdout is for emitting JSON lines of Events.
-func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt) (*HostAgent, error) {
+func New(instName string, stdout io.Writer, signalCh chan os.Signal, opts ...Opt) (*HostAgent, error) {
 	var o options
 	for _, f := range opts {
 		if err := f(&o); err != nil {
@@ -117,6 +119,7 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 	}
 
 	vSockPort := 0
+	virtioPort := ""
 	if *y.VMType == limayaml.VZ {
 		vSockPort = 2222
 	} else if *y.VMType == limayaml.WSL2 {
@@ -125,9 +128,12 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 			logrus.WithError(err).Error("failed to get free VSock port")
 		}
 		vSockPort = port
+	} else if *y.VMType == limayaml.QEMU {
+		// virtserialport doesn't seem to work reliably: https://github.com/lima-vm/lima/issues/2064
+		virtioPort = "" // filenames.VirtioPort
 	}
 
-	if err := cidata.GenerateISO9660(inst.Dir, instName, y, udpDNSLocalPort, tcpDNSLocalPort, o.nerdctlArchive, vSockPort); err != nil {
+	if err := cidata.GenerateISO9660(inst.Dir, instName, y, udpDNSLocalPort, tcpDNSLocalPort, o.nerdctlArchive, vSockPort, virtioPort); err != nil {
 		return nil, err
 	}
 
@@ -160,6 +166,7 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		Yaml:         y,
 		SSHLocalPort: sshLocalPort,
 		VSockPort:    vSockPort,
+		VirtioPort:   virtioPort,
 	})
 
 	a := &HostAgent{
@@ -173,9 +180,10 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		sshConfig:         sshConfig,
 		portForwarder:     newPortForwarder(sshConfig, sshLocalPort, rules, inst.VMType),
 		driver:            limaDriver,
-		sigintCh:          sigintCh,
+		signalCh:          signalCh,
 		eventEnc:          json.NewEncoder(stdout),
 		vSockPort:         vSockPort,
+		virtioPort:        virtioPort,
 		guestAgentAliveCh: make(chan struct{}),
 	}
 	return a, nil
@@ -411,8 +419,8 @@ func (a *HostAgent) startRoutinesAndWait(ctx context.Context, errCh chan error)
 			}
 			err := a.driver.Stop(ctx)
 			return err
-		case <-a.sigintCh:
-			logrus.Info("Received SIGINT, shutting down the host agent")
+		case sig := <-a.signalCh:
+			logrus.Infof("Received %s, shutting down the host agent", osutil.SignalName(sig))
 			cancelHA()
 			if closeErr := a.close(); closeErr != nil {
 				logrus.WithError(closeErr).Warn("an error during shutting down the host agent")
@@ -561,6 +569,9 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		}
 	}
 
+	localUnix := filepath.Join(a.instDir, filenames.GuestAgentSock)
+	remoteUnix := "/run/lima-guestagent.sock"
+
 	a.onClose = append(a.onClose, func() error {
 		logrus.Debugf("Stop forwarding unix sockets")
 		var errs []error
@@ -573,9 +584,19 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 				}
 			}
 		}
+		if a.driver.ForwardGuestAgent() {
+			if err := forwardSSH(context.Background(), a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbCancel, false); err != nil {
+				errs = append(errs, err)
+			}
+		}
 		return errors.Join(errs...)
 	})
 	for {
+		if a.client == nil || !isGuestAgentSocketAccessible(ctx, a.client) {
+			if a.driver.ForwardGuestAgent() {
+				_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbForward, false)
+			}
+		}
 		client, err := a.getOrCreateClient(ctx)
 		if err == nil {
 			if err := a.processGuestAgentEvents(ctx, client); err != nil {
@@ -610,8 +631,18 @@ func (a *HostAgent) getOrCreateClient(ctx context.Context) (guestagentclient.Gue
 	return a.client, err
 }
 
-func (a *HostAgent) createClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
+func (a *HostAgent) createConnection(ctx context.Context) (net.Conn, error) {
 	conn, err := a.driver.GuestAgentConn(ctx)
+	// default to forwarded sock
+	if conn == nil && err == nil {
+		var d net.Dialer
+		conn, err = d.DialContext(ctx, "unix", filepath.Join(a.instDir, filenames.GuestAgentSock))
+	}
+	return conn, err
+}
+
+func (a *HostAgent) createClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
+	conn, err := a.createConnection(ctx)
 	if err != nil {
 		return nil, err
 	}
