@@ -23,6 +23,7 @@ type LimaYAML struct {
 	Audio              Audio           `yaml:"audio,omitempty" json:"audio,omitempty"`
 	Video              Video           `yaml:"video,omitempty" json:"video,omitempty"`
 	Provision          []Provision     `yaml:"provision,omitempty" json:"provision,omitempty"`
+	UpgradePackages    *bool           `yaml:"upgradePackages,omitempty" json:"upgradePackages,omitempty"`
 	Containerd         Containerd      `yaml:"containerd,omitempty" json:"containerd,omitempty"`
 	GuestInstallPrefix *string         `yaml:"guestInstallPrefix,omitempty" json:"guestInstallPrefix,omitempty"`
 	Probes             []Probe         `yaml:"probes,omitempty" json:"probes,omitempty"`
@@ -39,6 +40,7 @@ type LimaYAML struct {
 	CACertificates    CACertificates `yaml:"caCerts,omitempty" json:"caCerts,omitempty"`
 	Rosetta           Rosetta        `yaml:"rosetta,omitempty" json:"rosetta,omitempty"`
 	Plain             *bool          `yaml:"plain,omitempty" json:"plain,omitempty"`
+	TimeZone          *string        `yaml:"timezone,omitempty" json:"timezone,omitempty"`
 }
 
 type (
